@@ -1,13 +1,11 @@
 <?php
+
 // Icinga Reporting | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\Reporting;
 
 class Reportlet
 {
-    /** @var int */
-    protected $id;
-
     /** @var string */
     protected $class;
 
@@ -15,23 +13,29 @@ class Reportlet
     protected $config;
 
     /**
-     * @return  int
-     */
-    public function getId()
-    {
-        return $this->id;
-    }
-
-    /**
-     * @param   int $id
+     * Create reportlet from the given model
      *
-     * @return  $this
+     * @param Model\Reportlet $reportletModel
+     *
+     * @return static
      */
-    public function setId($id)
+    public static function fromModel(Model\Reportlet $reportletModel): self
     {
-        $this->id = $id;
+        $reportlet = new static();
+        $reportlet->class = $reportletModel->class;
 
-        return $this;
+        $reportletConfig = [
+            'name' => $reportletModel->report_name,
+            'id'   => $reportletModel->report_id
+        ];
+
+        foreach ($reportletModel->config as $config) {
+            $reportletConfig[$config->name] = $config->value;
+        }
+
+        $reportlet->config = $reportletConfig;
+
+        return $reportlet;
     }
 
     /**
@@ -42,18 +46,6 @@ class Reportlet
         return $this->class;
     }
 
-    /**
-     * @param   string  $class
-     *
-     * @return  $this
-     */
-    public function setClass($class)
-    {
-        $this->class = $class;
-
-        return $this;
-    }
-
     /**
      * @return  array
      */
@@ -62,18 +54,6 @@ class Reportlet
         return $this->config;
     }
 
-    /**
-     * @param   array   $config
-     *
-     * @return  $this
-     */
-    public function setConfig($config)
-    {
-        $this->config = $config;
-
-        return $this;
-    }
-
     /**
      * @return  \Icinga\Module\Reporting\Hook\ReportHook
      */
@@ -81,6 +61,6 @@ class Reportlet
     {
         $class = $this->getClass();
 
-        return new $class;
+        return new $class();
     }
 }
